@@ -1,4 +1,6 @@
-# Copyright (C) 2003-2005 Nominum, Inc.
+# Copyright (C) Dnspython Contributors, see LICENSE for text of ISC license
+
+# Copyright (C) 2003-2007, 2009-2011 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -18,8 +20,14 @@
 __all__ = [
     'ANY',
     'IN',
+    'CH',
+    'dnskeybase',
+    'dsbase',
+    'euibase',
     'mxbase',
     'nsbase',
-    'sigbase',
-    'keybase',
+    'svcbbase',
+    'tlsabase',
+    'txtbase',
+    'util'
 ]
