@@ -209,7 +209,7 @@ def test_bad_parameters(db):
         with pytest.raises(ValueError):
             foo = dns.name.from_text('foo', None)
             rdata = dns.rdata.from_text('in', 'a', '10.0.0.3')
-            txn.add(foo, 0x80000000, rdata)
+            txn.add(foo, 0x100000000, rdata)
         with pytest.raises(TypeError):
             txn.add(foo)
         with pytest.raises(TypeError):
@@ -322,7 +322,7 @@ def test_explicit_rollback_and_commit(zone):
         with zone.writer() as txn:
             txn.rollback()
             for rdataset in txn:
-                print(rdataset)
+                pass
 
 def test_zone_changed(zone):
     # Read-only is not changed!
@@ -417,7 +417,6 @@ def test_write_after_rollback(zone):
 
 def test_zone_get_deleted(zone):
     with zone.writer() as txn:
-        print(zone.to_text())
         ns1 = dns.name.from_text('ns1', None)
         assert txn.get(ns1, dns.rdatatype.A) is not None
         txn.delete(ns1)
@@ -471,9 +470,9 @@ class ExpectedException(Exception):
     pass
 
 def test_zone_rollback(zone):
+    a99 = dns.name.from_text('a99.example.')
     try:
         with zone.writer() as txn:
-            a99 = dns.name.from_text('a99.example.')
             rds = dns.rdataset.from_text('in', 'a', 300, '10.0.0.99')
             txn.add(a99, rds)
             assert txn.name_exists(a99)
@@ -498,6 +497,35 @@ def test_zone_iteration(zone):
             actual[(name, rdataset.rdtype, rdataset.covers)] = rdataset
     assert actual == expected
 
+def test_iteration_in_replacement_txn(zone):
+    rds = dns.rdataset.from_text('in', 'a', 300, '1.2.3.4', '5.6.7.8')
+    expected = {}
+    expected[(dns.name.empty, rds.rdtype, rds.covers)] = rds
+    with zone.writer(True) as txn:
+        txn.replace(dns.name.empty, rds)
+        actual = {}
+        for (name, rdataset) in txn:
+            actual[(name, rdataset.rdtype, rdataset.covers)] = rdataset
+    assert actual == expected
+
+def test_replacement_commit(zone):
+    rds = dns.rdataset.from_text('in', 'a', 300, '1.2.3.4', '5.6.7.8')
+    expected = {}
+    expected[(dns.name.empty, rds.rdtype, rds.covers)] = rds
+    with zone.writer(True) as txn:
+        txn.replace(dns.name.empty, rds)
+    with zone.reader() as txn:
+        actual = {}
+        for (name, rdataset) in txn:
+            actual[(name, rdataset.rdtype, rdataset.covers)] = rdataset
+    assert actual == expected
+
+def test_replacement_get(zone):
+    with zone.writer(True) as txn:
+        rds = txn.get(dns.name.empty, 'soa')
+        assert rds is None
+
+
 @pytest.fixture
 def vzone():
     return dns.zone.from_text(example_text, zone_factory=dns.versioned.Zone)
